@@ -717,25 +717,6 @@ ngx_streaming_handler_paths(ngx_http_request_t *r, mp4_process_context_t* ctx)
     ngx_open_file_info_t of;
     http_status = open_path(r, clcf, &path, &of);
 
-    // backwards compatibility check
-    if(http_status == NGX_DECLINED)
-    {
-      if(of.is_dir)
-      {
-        char new_path[4096];
-        char const* path_first = (char const*)path.data;
-        char const* path_last = path_first + path.len;
-        mp4_rewrite_dir(path_first, path_last, new_path, sizeof(new_path));
-        path.len = strlen(new_path);
-        path.data = ngx_pnalloc(r->pool, path.len + 1);
-        ngx_memcpy(path.data, new_path, path.len);
-        path.data[path.len] = '\0';
-        ngx_log_debug2(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
-                       "ngx_streaming_handler_paths: is_dir \"%V?%V\"", &path, &r->args);
-        http_status = open_path(r, clcf, &path, &of);
-      }
-    }
-
 #if 0 // don't rely on (stale) file metadata
     if(http_status == NGX_OK)
     {
@@ -1218,7 +1199,29 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
     // compute expiry with seconds accuracy for interoperable results with nginx
     typedef uint64_t seconds_t;
 
-    // Add Cache-Control and Expires (see also ngx_http_headers_filter_module.c)
+    // Add X-USP-Last-Modified
+    if(headers->updated_at_experimental_)
+    {
+      seconds_t updated_time = headers->updated_at_experimental_ / 1000000;
+      ngx_table_elt_t* h = ngx_list_push(&r->headers_out.headers);
+      if(h == NULL)
+      {
+        return NGX_HTTP_INTERNAL_SERVER_ERROR;
+      }
+      h->hash = 1;
+      h->key.len = sizeof("X-USP-Last-Modified") - 1;
+      h->key.data = (u_char*)"X-USP-Last-Modified";
+      h->value.len = sizeof("Mon, 28 Sep 1970 06:00:00 GMT") - 1;
+      h->value.data =
+        ngx_pnalloc(r->pool, sizeof("Mon, 28 Sep 1970 06:00:00 GMT"));
+      if(h->value.data == NULL)
+      {
+        return NGX_ERROR;
+      }
+      ngx_http_time(h->value.data, updated_time);
+    }
+
+     // Add Cache-Control and Expires (see also ngx_http_headers_filter_module.c)
     {
       ngx_str_t cache_control = ngx_null_string;
       ngx_str_t expires = ngx_null_string;
